@@ -109,7 +109,7 @@ def handle_new_packages(
             project.update_settings({"allow_prereleases": pre})
 
     # Use the update routine for new packages
-    if perform_upgrades:
+    if perform_upgrades and (packages or editable_packages):
         try:
             do_update(
                 project,
@@ -158,18 +158,19 @@ def handle_lockfile(
                     style="red",
                 )
                 raise exceptions.DeployException
-            handle_outdated_lockfile(
-                project,
-                packages,
-                old_hash=old_hash,
-                new_hash=new_hash,
-                system=system,
-                allow_global=allow_global,
-                skip_lock=skip_lock,
-                pre=pre,
-                pypi_mirror=pypi_mirror,
-                categories=categories,
-            )
+            elif not system:
+                handle_outdated_lockfile(
+                    project,
+                    packages,
+                    old_hash=old_hash,
+                    new_hash=new_hash,
+                    system=system,
+                    allow_global=allow_global,
+                    skip_lock=skip_lock,
+                    pre=pre,
+                    pypi_mirror=pypi_mirror,
+                    categories=categories,
+                )
     elif not project.lockfile_exists and not skip_lock:
         handle_missing_lockfile(project, system, allow_global, pre, pypi_mirror)
 
@@ -281,17 +282,6 @@ def do_install(
         pipfile_categories=pipfile_categories,
     )
 
-    do_init(
-        project,
-        package_args,
-        system=system,
-        allow_global=system,
-        deploy=deploy,
-        pypi_mirror=pypi_mirror,
-        skip_lock=skip_lock,
-        categories=pipfile_categories,
-    )
-
     do_install_validations(
         project,
         package_args,
@@ -305,7 +295,19 @@ def do_install(
         categories=pipfile_categories,
         skip_lock=skip_lock,
     )
-    if not deploy:
+
+    do_init(
+        project,
+        package_args,
+        system=system,
+        allow_global=system,
+        deploy=deploy,
+        pypi_mirror=pypi_mirror,
+        skip_lock=skip_lock,
+        categories=pipfile_categories,
+    )
+
+    if not (deploy or system):
         new_packages, _ = handle_new_packages(
             project,
             packages,
@@ -322,7 +324,7 @@ def do_install(
 
     try:
         if dev:  # Install both develop and default package categories from Pipfile.
-            pipfile_categories = ["default", "develop"]
+            pipfile_categories = ["packages", "dev-packages"]
         do_install_dependencies(
             project,
             dev=dev,
